// Set new default font family and font color to mimic Bootstrap's default styling
Chart.defaults.global.defaultFontFamily = 'Nunito', '-apple-system,system-ui,BlinkMacSystemFont,"Segoe UI",Roboto,"Helvetica Neue",Arial,sans-serif';
Chart.defaults.global.defaultFontColor = '#858796';

function revenue_areachart() {
	// Area Chart Example
	var area_day = $.trim($('.area_graph_day').text());
	var area_revenue = $.trim($('.area_graph_revenue').text());
	
	if(area_day && area_revenue){
		var ctx = document.getElementById("myAreaChart");
		var myLineChart = new Chart(ctx, {
		  type: 'line',
		  data: {
		    labels: JSON.parse(area_day),
		    datasets: [{
		      label: "Earnings",
		      lineTension: 0.3,
		      backgroundColor: "rgba(78, 115, 223, 0.05)",
		      borderColor: "rgba(78, 115, 223, 1)",
		      pointRadius: 3,
		      pointBackgroundColor: "rgba(78, 115, 223, 1)",
		      pointBorderColor: "rgba(78, 115, 223, 1)",
		      pointHoverRadius: 3,
		      pointHoverBackgroundColor: "rgba(78, 115, 223, 1)",
		      pointHoverBorderColor: "rgba(78, 115, 223, 1)",
		      pointHitRadius: 10,
		      pointBorderWidth: 2,
		      data: JSON.parse(area_revenue),
		    }],
		  },
		  options: {
		    maintainAspectRatio: false,
		    layout: {
		      padding: {
		        left: 10,
		        right: 25,
		        top: 25,
		        bottom: 0
		      }
		    },
		    scales: {
		      xAxes: [{
		        time: {
		          unit: 'date'
		        },
		        gridLines: {
		          display: false,
		          drawBorder: false
		        },
		        ticks: {
		          maxTicksLimit: 7
		        }
		      }],
		      yAxes: [{
		        ticks: {
		          min : 0,
		          maxTicksLimit: 5,
		          padding: 10,
		          // Include a dollar sign in the ticks
		          callback: function(value, index, values) {
		            return '$' + number_format(value);
		          }
		        },
		        gridLines: {
		          color: "rgb(234, 236, 244)",
		          zeroLineColor: "rgb(234, 236, 244)",
		          drawBorder: false,
		          borderDash: [2],
		          zeroLineBorderDash: [2]
		        }
		      }],
		    },
		    legend: {
		      display: false
		    },
		    tooltips: {
		      backgroundColor: "rgb(255,255,255)",
		      bodyFontColor: "#858796",
		      titleMarginBottom: 10,
		      titleFontColor: '#6e707e',
		      titleFontSize: 14,
		      borderColor: '#dddfeb',
		      borderWidth: 1,
		      xPadding: 15,
		      yPadding: 15,
		      displayColors: false,
		      intersect: false,
		      mode: 'index',
		      caretPadding: 10,
		      callbacks: {
		        label: function(tooltipItem, chart) {
		          var datasetLabel = chart.datasets[tooltipItem.datasetIndex].label || '';
		          return datasetLabel + ': $ ' + tooltipItem.yLabel;
		        }
		      }
		    }
		  }
		});
	}
}

// Pie Chart Example
function gender_piechart() {
	var gender_female = $('.female').text();
	var gender_male = $('.male').text();
	if(gender_male && gender_female) {
		var ctx = document.getElementById("myPieChart");
		var myPieChart = new Chart(ctx, {
		  type: 'doughnut',
		  data: {
		    labels: ["Female", "Male"],
		    datasets: [{
		      data: [gender_female, gender_male],
		      backgroundColor: ['#EA526F', '#4e73df'],
		      hoverBackgroundColor: ['#ef4263', '#2e59d9'],
		      hoverBorderColor: "rgba(234, 236, 244, 1)",
		    }],
		  },
		  options: {
		    maintainAspectRatio: false,
		    tooltips: {
		      backgroundColor: "rgb(255,255,255)",
		      bodyFontColor: "#858796",
		      borderColor: '#dddfeb',
		      borderWidth: 1,
		      xPadding: 15,
		      yPadding: 15,
		      displayColors: false,
		      caretPadding: 10,
		      callbacks: {
				label: function(tooltipItem, chart) {
			      if(tooltipItem.index == "0"){
			      	var chartindex = "1";
			      } else {
			      	var chartindex = "0";
			      }
			      return chart.labels[chartindex] + ' : ' + chart.datasets[0]['data'][tooltipItem.index] + '%';
				}
		      }
		    },
		    legend: {
		      display: false
		    },
		    cutoutPercentage: 80,
		  },
		});
	}
}

// Bar Chart
function bar_chart(container, sort) {
	//var maledata = $.trim($('.maledata').text());
		
		if(sort == 'male'){
			data = $('.maledata').text();
			bgcolor = "#4e73df";
			hbgcolor = "#2e59d9";
			bdcolor = "#4e73df";
		} else if(sort == 'female'){
			data = $('.femaledata').text();
			bgcolor = "#EA526F";
			hbgcolor = "#ef4263";
			bdcolor = "#EA526F";
		} else if(sort == 'total'){
			data = $('.totaldata').text();
			bgcolor = "#1cc88a";
			hbgcolor = "#17a673";
			bdcolor = "#4e73df";
		}

		var ctx = document.getElementById(container);
		var myBarChart = new Chart(ctx, {
		  type: 'bar',
		  data: {
		    labels: ["18-24", "25-34", "35-44", "45-54", "55-64", "65+"],
		    datasets: [{
		      label: "Percent",
		      backgroundColor: bgcolor,
		      hoverBackgroundColor: hbgcolor,
		      borderColor: bdcolor,
		      data: JSON.parse(data),
		    }],
		  },
		  options: {
		    maintainAspectRatio: false,
		    layout: {
		      padding: {
		        left: 10,
		        right: 25,
		        top: 25,
		        bottom: 0
		      }
		    },
		    scales: {
		      yAxes: [{
		        ticks: {
		          min: 0,
		          // Include a dollar sign in the ticks
		          callback: function(value, index, values) {
		            return number_format(value) + '%';
		          }
		        },
		        gridLines: {
		          color: "rgb(234, 236, 244)",
		          zeroLineColor: "rgb(234, 236, 244)",
		          drawBorder: false,
		          borderDash: [2],
		          zeroLineBorderDash: [2]
		        }
		      }],
		    },
		    legend: {
		      display: false
		    },
		    tooltips: {
		      titleMarginBottom: 10,
		      titleFontColor: '#6e707e',
		      titleFontSize: 16,
		      backgroundColor: "rgb(255,255,255)",
		      bodyFontColor: "#858796",
		      borderColor: '#dddfeb',
		      borderWidth: 1,
		      xPadding: 15,
		      yPadding: 15,
		      displayColors: false,
		      caretPadding: 10,
		      callbacks: {
		        label: function(tooltipItem, chart) {
		          return number_format(tooltipItem.yLabel) + '%';
		        }
		      }
		    },
		  }
		});
}


function number_format(number, decimals, dec_point, thousands_sep) {
  // *     example: number_format(1234.56, 2, ',', ' ');
  // *     return: '1 234,56'
  number = (number + '').replace(',', '').replace(' ', '');
  var n = !isFinite(+number) ? 0 : +number,
    prec = !isFinite(+decimals) ? 0 : Math.abs(decimals),
    sep = (typeof thousands_sep === 'undefined') ? ',' : thousands_sep,
    dec = (typeof dec_point === 'undefined') ? '.' : dec_point,
    s = '',
    toFixedFix = function(n, prec) {
      var k = Math.pow(10, prec);
      return '' + Math.round(n * k) / k;
    };
  // Fix for IE parseFloat(0.55).toFixed(0) = 0;
  s = (prec ? toFixedFix(n, prec) : '' + Math.round(n)).split('.');
  if (s[0].length > 3) {
    s[0] = s[0].replace(/\B(?=(?:\d{3})+(?!\d))/g, sep);
  }
  if ((s[1] || '').length < prec) {
    s[1] = s[1] || '';
    s[1] += new Array(prec - s[1].length + 1).join('0');
  }
  return s.join(dec);
}
$( document ).ready(function() {
	$.exec_json('ga.procGaAjaxTemplate', {url:window.location.href},
		function(data) {
			
			if(data.url){
				$('.pageGoogle').empty().html('<a href="' + data.url + '">Link Google Analytics</a>');
				return false;
			}	
			
			if(data.cache){
				$('.pageGoogle').empty().html(data.cache);
			} else {
				// Page
				$('.pageGoogle').html(data.page);
				
				// Value
				$('.today-earning').html(data.today_earning);
				$('.month-earning').html(data.month_earning);
				$('.today-pv').html(data.pv);
				$('.avgonpage').html(data.avgonpage);
				
				$('.t-cpc').html(data.cpc);
				$('.t-clicks').html(data.clicks);
				$('.t-ctr').html(data.ctr);
				$('.t-rpm').html(data.rpm);
				
				// Area Chart
				$('.area_graph_day').html(data.month_day);
				$('.area_graph_revenue').html(data.month_revenue_day);
				
				// Pie Chart
				$('.gender_data').html(data.piechartdata);
				
				// Table
				$('.page_cnt').html(data.page_cnt);
				$('#dataTable tbody').empty().html(data.table);
				$('#dataTable tfoot tr').html(data.tablefoot);
				
				// Bar Chart
				$('.maledata').text(data.maleHtml);
				$('.femaledata').text(data.femaleHtml);
				$('.totaldata').text(data.totalHtml);
				
				// Update cache;
				$.exec_json('ga.procGaUpdateCache', {html: $('.pageGoogle').html()},function(data) { });
			}
			
			// Chart and Table
			revenue_areachart(); // Area Chart
			gender_piechart(); // Pie Chart
			bar_chart("myBarChart", "male"); // Bar Chart
			bar_chart("myBarChart2", "female"); // Bar Chart
			bar_chart("myBarChart3", "total"); // Bar Chart
			$('#dataTable').DataTable({ "order": []	}); // Table
			
			// DatePicker
			$('.input-daterange .start_date, .input-daterange .end_date').datepicker({
				todayHighlight: true,
				autoclose: true,
			    format: "yyyy-mm-dd",
			    language : "ko",
			    container : $('.datepicker-container'),
			    orientation: 'top' 
			});
		},
		// failure
		function(response) {
		}
	);
});


$(document).on("click","#dateSubmit",function() {
	$('.text-daterange .start_log').text($.trim($('.input-daterange .start_date').val()));
	$('.text-daterange .end_log').text($.trim($('.input-daterange .end_date').val()));
	
	var that = $(this);
	var start_date = $('.text-daterange .start_log').text();
	var end_date = $('.text-daterange .end_log').text();
	var page_cnt = $('.text-daterange .page_cnt').text();
	
	that.html('<i class="fas fa-redo fa-spin text-primary"></i>');
	
	$.exec_json('ga.procGaAjax', {start_date: start_date, end_date : end_date, sort : "table", page_cnt : page_cnt},
	function(data) {
		that.html('Submit');
    	$('#dataTable').DataTable().clear().destroy();
    	$('#dataTable tbody').empty().html(data.ajaxdata);
    	$('#dataTable tfoot tr').html(data.tablefoot);
    	$('#dataTable').DataTable({ "order": []	});
	},
	// failure
	function(response) {
		that.html('Submit');
	    alert("Error. Retry Please");
	});
});	

$(document).on("click",".btnGender",function() {
	
	var that = $(this);
	var start_date = $.trim($('.text-daterange .start_log').text());
	var end_date = $.trim($('.text-daterange .end_log').text());
	$(this).html('<i class="fas fa-redo fa-spin text-primary"></i>');
	
	$.exec_json('ga.procGaAjax', {start_date: start_date, end_date : end_date, sort : "gender"},
	function(data) {
		
		$('.dataTable .btnGender').addClass('text-gray-300').text('No Data');
		$(data.ajaxdata).each(function(index) {
			$('.dataTable tbody tr td a[href*="' + this['path'] + '"]').parent().parent().find('.btnGender').removeClass('text-gray-300').addClass('text-primary');
			$('.dataTable tbody tr td a[href*="' + this['path'] + '"]').parent().parent().find('.btnGender').text(this['male'] + '% : ' + this['female'] + '%');
		});
	},
	// failure
	function(response) {
		that.html('남녀비율');
	    alert("잠시 후 재시도 해주세요.");
	});
});	

$(document).on("click",".btnAge",function() {
	
	var that = $(this);
	var start_date = $.trim($('.input-daterange .start_date').val());
	var end_date = $.trim($('.input-daterange .end_date').val());
	$(this).html('<i class="fas fa-redo fa-spin text-primary"></i>');
	
	$.exec_json('ga.procGaAjax', {start_date: start_date, end_date : end_date, sort : "age"},
	function(data) {
		
			$('.dataTable .btnAge').addClass('text-gray-300').text('No Data');
			$(data.ajaxdata).each(function(index) {
				$('.dataTable tbody tr td a[href*="' + this['path'] + '"]').parent().parent().find('.btnAge').removeClass('text-gray-300').addClass('text-primary text-xs');
				$('.dataTable tbody tr td a[href*="' + this['path'] + '"]').parent().parent().find('.btnAge').html(this['html']);
			});
	},
	// failure
	function(response) {
		that.html('연령대');
	    alert("잠시 후 재시도 해주세요.");
	});
    
});	


$(document).on("click",".gender_today, .gender_yesterday, .gender_week",function(){

	if($(this).text() == "Today"){
		start_date = "today";
		end_date = "today";
	} else if($(this).text() == "Yesterday"){
		start_date = "1daysAgo";
		end_date = "1daysAgo";
	} else if($(this).text() == "Week"){
		start_date = "6daysAgo";
		end_date = "today";
	}
	$('#myPieChart').remove();
	$('.chart-pie').html('<i class="fas fa-redo fa-spin text-primary text-big-rotate"></i>');
   
   
    $.exec_json('ga.procGaAjax', {start_date: start_date, end_date : end_date, sort : "gender_range"},
	function(data) {
		
		$('.chart-pie').html('<canvas id="myPieChart"></canvas>');
    	$('.gender_data').html(data.ajaxdata);
		gender_piechart();	
	},
	// failure
	function(response) {
	    alert("잠시 후 재시도 해주세요.");
	});
    
});	
